@extends('laundry::layouts/contentLayoutMaster')

@section('title', __('Inventory Status') )

@section('vendor-style')
  {{-- vendor css files --}}
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/tables/datatable/dataTables.bootstrap4.min.css')) }}">
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/tables/datatable/responsive.bootstrap4.min.css')) }}">
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/tables/datatable/buttons.bootstrap4.min.css')) }}">
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/tables/datatable/rowGroup.bootstrap4.min.css')) }}">
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/pickers/flatpickr/flatpickr.min.css')) }}">
  <link rel="stylesheet" href="https://pro.fontawesome.com/releases/v5.10.0/css/all.css" integrity="sha384-AYmEC3Yw5cVb3ZcuHtOA93w35dYTsvhLPVnYs9eStHfGJvOvKxVfELGroGkvsg+p" crossorigin="anonymous"/>
  
  @livewireStyles
@endsection
@section('page-style')
  <!-- Page css files -->
  <style>
    .dataTables_info{
      padding-left: 15px;
    }
    .dataTables_length{
      padding-left: 15px;
    }
    .pagination{
      padding-right: 15px;
    }
    .dataTables_filter{
      padding-right: 15px;
    }
  
  .buttons-copy{
    margin-left: 15px;
  }
  .buttons-html5{
    margin-top: 15px;
    box-shadow: none;
    display: inline-block;
    font-weight: 400;
    color: #6e6b7b;
    text-align: center;
    vertical-align: middle;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    background-color: transparent;
    border: 1px solid transparent;
    border-top-color: transparent;
    border-right-color: transparent;
    border-bottom-color: transparent;
    border-left-color: transparent;
    padding: 0.786rem 1.5rem;
    font-size: 1rem;
    line-height: 1;
    border-radius: 0.358rem;
    transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out, background 0s, border 0s;
    border-color: #7367f0 !important;
    background-color: #7367f0 !important;
    color: #fff !important;
  }
    </style>
  @endsection

  

@section('content')
@if(session()->has('message'))
    <div class="alert alert-success p-2" role="alert">
        {{ session()->get('message') }}
    </div>
@endif

@if($errors->any())
    {!! implode('', $errors->all('<div class="alert alert-danger p-2" role="alert">:message</div>')) !!}
@endif

<!-- Basic table -->
<section id="basic-datatable">
  <div class="row">
    <div class="col-12">
      <div class="card">

        <div class="card-body">

            <div class="modal-body flex-grow-1 row">
              <div class="form-group col-md-5">
                  <label class="form-label" for="basic-icon-default-fullname">{{ __('Category') }}</label>
                  <select class="form-control"
                    id="category"
                    name="category_id"
                    onchange="getSubCat()"
                    required>
                    <option value="">{{ __('Select Category') }}</option>
                    @foreach($categories as $category)
                      <option value="{{$category->id}}" @if(isset($_GET['cat'])) {{ $_GET['cat'] == $category->id ? 'selected' : '' }} @endif >{{$category->name}}</option>
                    @endforeach
                    required
                  </select>
              </div>
              <div class="form-group col-md-5">
                  <label class="form-label" for="basic-icon-default-fullname">{{ __('Sub Category') }}</label>
                  <select class="form-control"
                    id="subcategory"
                    name="subcategory_id"
                    required
                    disabled>
                    <option value="">{{ __('Select Sub Category') }}</option>
                  </select>
              </div>
              <div class="form-group col-md-2">
              <label class="form-label" for="basic-icon-default-fullname"> </label>
                  <button onclick="reloadWithParams()" class="btn btn-primary form-control">{{ __('Search') }}</button>
              </div>
             

              <div class="form-group col-md-6">
                <br/>
                <h5>{{ __('Quantity') }}: <span id="totalTags">{{ count($items) }}</span></h5>
              </div>
              
            </div>
          
        </div>

        <table id="rfidtable" class="table" style="width:100%">
          <thead>
              <tr>
                <th>#</th>
                <th>{{ __('Category') }}</th>
                <th>{{ __('Sub Category') }}</th>
                <th>{{ __('RFID') }}</th>
                <th>{{ __('Date') }}</th>
                <th>{{ __('Status') }}</th>
                <th>{{ __('Action') }}</th>
              </tr>
          </thead>
          <tbody>
              <?php $i=0 ?>
              @foreach($items as $item)
                <?php $i++;
                $itemLastProcess = $item->process_stock->last(); // just to save for another query
                ?>
                <tr>
                  <td>{{ $i }}</td>
                  <td>{{ $item->inventory->category->name }}</td>
                  <td>{{ $item->inventory->subcategory->name }}</td>
                  <td>{{ $item->rfid }}</td>
                  <td>{{ str_replace(' ', ' | ', $itemLastProcess==null ? '' : $itemLastProcess->created_at)}}</td>
                  <td>{{ $itemLastProcess==null ? '' : $itemLastProcess->prity_status }} {{ $itemLastProcess==null ? '' : $itemLastProcess->realloc ? '*' : '' }} </td>
                  <td>
                    @if($itemLastProcess==null ? '' : $itemLastProcess->status!='reallocated')  
                      <li class="fa fa-edit text-primary cursor-pointer"
                        data-toggle="modal"
                        data-target="#actionModel"
                        onclick="$('.itemid').val('{{ $item->id }}'); $('#actionModel').modal('show');"></li>
                    @endif
                  </td>
                      
                </tr>
              @endforeach
          </tbody>
        </table>

      </div>
    </div>
  </div>
</section>


<div class="modal-size-default d-inline-block">
  <!-- Modal -->
  <div class="modal fade text-left" id="actionModel" tabindex="-1" role="dialog"
        aria-labelledby="myModalLabel18" aria-hidden="true">
      <div class="modal-dialog modal-dialog-centered" role="document">
          <div class="modal-content">
              <div class="modal-header">
                  <h4 class="modal-title" id="myModalLabel18">{{ __('Change Item Status') }}</h4>
                  <button type="button" class="close" data-dismiss="modal" aria-label="Close" onclick="$('#actionModel').modal('hide');">
                      <span aria-hidden="true">&times;</span>
                  </button>
              </div>
              <div class="modal-body">
                <textarea id="notetext"
                  class="form-control"
                  placeholder="{{ __('Please describe the reason') }}"
                  oninput="$('.note').val($(this).val())"></textarea>
                <br/>
                
              </div>
              <div class="modal-footer">

                <form method="post" action="{{ url('/laundry/stock/process/save') }}">
                  @csrf
                  <input type="hidden" name="id" class="itemid">
                  <input type="hidden" name="purpose" value="damaged">
                  <input type="hidden" name="note" class="note">
                  <input type="hidden" name="reallocated" class="itemreallocated">
                  <input type="submit" value="Damage" class="btn btn-primary">
                </form>

                
                <form method="post" action="{{ url('/laundry/stock/process/save') }}">
                  @csrf
                  <input type="hidden" name="id" class="itemid">
                  <input type="hidden" name="purpose" value="lost">
                  <input type="hidden" name="note" class="note">
                  <input type="hidden" name="reallocated" class="itemreallocated">
                  <input type="submit" value="Lost" class="btn btn-primary">
                </form>
                
              </div>
          </div>
      </div>
  </div>
</div>


@endsection


@section('vendor-script')
  @livewireScripts
  {{-- vendor files --}}
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/jquery.dataTables.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/datatables.bootstrap4.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/dataTables.responsive.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/responsive.bootstrap4.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/datatables.checkboxes.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/datatables.buttons.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/jszip.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/pdfmake.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/vfs_fonts.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/buttons.html5.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/buttons.print.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/dataTables.rowGroup.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/pickers/flatpickr/flatpickr.min.js')) }}"></script>
@endsection
@section('page-script')
  {{-- Page js files --}}
  <!-- <script src="{{ asset(('laundry-files/js/scripts/tables/table-datatables-basic.js')) }}"></script> -->
  <script>
  const rfidTagsList = [];
  var table;
  // for input
  var rfidTableParams = {
      "bPaginate": false,
      "bLengthChange": false,
      "bFilter": false,
      "bInfo": false,
      "bAutoWidth": false,
      "ordering": false,
      "columnDefs": [{ "width": "20%", "targets": 1 }]
    };

  $(document).ready(function() {
    table = $('#rfidtable').DataTable({
      "bPaginate": true,
      "bLengthChange": true,
      "bFilter": true,
      "bInfo": true,
      "bAutoWidth": true,
      "ordering": true,
      "columnDefs": [{ "width": "5%", "targets": 0 }],
      dom: 'Bfrtip',
        buttons: [
            'copyHtml5',
            'excelHtml5',
            'csvHtml5',
            'pdfHtml5'
        ]
    });

    var rfidTable = $('#rfidinputtable').DataTable(rfidTableParams);

    @if(isset($_GET['cat']))
      getSubCat();
    @endif
    
  });

  function getSubCat(){
    var dept = $('#category').val();
    $.get("{{ url('/laundry/subcatList') }}", {id: dept}, function(result){
      $('#subcategory').html('<option value="">Select Sub Category</option>'+result);
      $('#subcategory').prop('disabled', false);
      
      @if(isset($_GET['subcat']) && $_GET['subcat']!='')
      $('#subcategory').val('<?php echo $_GET['subcat'] ?>');
      @endif

    });
  }

  function reloadWithParams(){
    window.location = "{{ url('/laundry/reports/status') }}?cat=" + $('#category').val() + "&subcat=" + $('#subcategory').val();
  }
  
  </script>
@endsection
