@extends('laundry::layouts/contentLayoutMaster')

@section('title', __('Add New User') )

@section('vendor-style')
  {{-- vendor css files --}}
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/tables/datatable/dataTables.bootstrap4.min.css')) }}">
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/tables/datatable/responsive.bootstrap4.min.css')) }}">
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/tables/datatable/buttons.bootstrap4.min.css')) }}">
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/tables/datatable/rowGroup.bootstrap4.min.css')) }}">
  <link rel="stylesheet" href="{{ asset(('laundry-files/vendors/css/pickers/flatpickr/flatpickr.min.css')) }}">
  <link rel="stylesheet" href="https://pro.fontawesome.com/releases/v5.10.0/css/all.css" integrity="sha384-AYmEC3Yw5cVb3ZcuHtOA93w35dYTsvhLPVnYs9eStHfGJvOvKxVfELGroGkvsg+p" crossorigin="anonymous"/>
  
  @livewireStyles
@endsection
@section('page-style')
  <!-- Page css files -->
  <style>
    .dataTables_info{
      padding-left: 15px;
    }
    .dataTables_length{
      padding-left: 15px;
    }
    .pagination{
      padding-right: 15px;
    }
    .dataTables_filter{
      padding-right: 15px;
    }
    </style>
  @endsection

  

@section('content')
@if(session()->has('message'))
    <div class="alert alert-success p-2" role="alert">
        {{ session()->get('message') }}
    </div>
@endif

@if($errors->any())
    {!! implode('', $errors->all('<div class="alert alert-danger p-2" role="alert">:message</div>')) !!}
@endif

<form id="formid" method="post" action="{{ url('/laundry/roles/save') }}" >
@csrf
<!-- Basic table -->
<section id="basic-datatable">
  <div class="row">
    <div class="col-12">
      <div class="card">

        <div class="card-body">
          
            <input name="id" id="id" value="{{ $user==null ? '' : $user->id }}" type="hidden"/>
            
            <div class="modal-body flex-grow-1">
            
            @if($user!=null)
              <div class="form-group">
                <label class="form-label text-success" for="basic-icon-default-fullname">{{ __('Enabled') }}</label>
                <input
                  type="checkbox"
                  id="enabled"
                  name="enabled"
                  {{ $user->status ? 'checked' : '' }}
                />
              </div>
              <br/>
            @endif

              <br/>
              <h4>User detail</h4> 
              <div class="row">
                <div class="form-group col-md-6">
                  <label class="form-label" for="basic-icon-default-fullname">{{ __('Role type') }}</label>
                  <select
                    class="form-control dt-full-name"
                    id="role_id"
                    name="role_id"
                    required>
                    @foreach($roles as $role)
                      <option value="{{ $role->id }}" {{ $role->id==$user->roleUser->role->id ? 'selected' : '' }}>{{ $role->name }}</option>
                    @endforeach
                  </select>
                </div>
                <div class="form-group col-md-6">
                  <label class="form-label" for="basic-icon-default-fullname">{{ __('Name') }}</label>
                  <input
                    type="text"
                    class="form-control dt-full-name"
                    placeholder="{{ __('Enter name') }}"
                    id="name"
                    name="name"
                    value="{{ $user==null ? '' : $user->name }}"
                    aria-label="Enter name"
                    aria-describedby="basic-icon-default-fullname2"
                    required
                  />
                </div>
                <div class="form-group col-md-6">
                  <label class="form-label" for="basic-icon-default-phone">{{ __('Phone number') }}</label>
                  <input
                    type="text"
                    class="form-control dt-full-name"
                    placeholder="{{ __('Phone') }}"
                    id="phone"
                    name="phone"
                    value="{{ $user==null ? '' : $user->phone }}"
                    aria-label="Phone"
                    aria-describedby="basic-icon-default-phone"
                    required
                  />
                </div>
                <div class="form-group col-md-6">
                  <label class="form-label" for="basic-icon-default-email">{{ __('Email') }}</label>
                  <input
                    type="text"
                    class="form-control dt-full-name"
                    placeholder="{{ __('Email') }}"
                    id="email"
                    name="email"
                    value="{{ $user==null ? '' : $user->email }}"
                    aria-label="Email"
                    aria-describedby="basic-icon-default-email"
                    required
                  />
                </div>
                <div class="form-group col-md-6">
                  <label class="form-label" for="basic-icon-default-address">{{ __('Password') }} {{ $user!=null ? '(LEAVE BLANK IF NO CHANGE)' : '' }}</label>
                  <input
                    type="password"
                    class="form-control dt-full-name"
                    placeholder="{{ __('Password') }}"
                    id="password"
                    name="password"
                    aria-label="Password"
                    aria-describedby="basic-icon-default-address"
                    required
                  />
                </div>

              </div>
              
              <div class="text-right">
                <br/>
                <button type="button" id="submitBtn" onclick="$('#formid').submit();" class="btn btn-primary mr-1 data-submit" >Submit</button>
              </div>
              
            </div>
          
        </div>

        
        

      </div>
    </div>
  </div>
</section>
<!--/ Basic table -->
</form>




@endsection


@section('vendor-script')
  @livewireScripts
  {{-- vendor files --}}
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/jquery.dataTables.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/datatables.bootstrap4.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/dataTables.responsive.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/responsive.bootstrap4.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/datatables.checkboxes.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/datatables.buttons.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/jszip.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/pdfmake.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/vfs_fonts.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/buttons.html5.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/buttons.print.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/tables/datatable/dataTables.rowGroup.min.js')) }}"></script>
  <script src="{{ asset(('laundry-files/vendors/js/pickers/flatpickr/flatpickr.min.js')) }}"></script>
@endsection
@section('page-script')
  {{-- Page js files --}}
  <!-- <script src="{{ asset(('laundry-files/js/scripts/tables/table-datatables-basic.js')) }}"></script> -->
  <script>

  $(document).ready(function() {
    

  });


  
  </script>
@endsection
